Module zero_crypto::behave
source · Traits
rational point affine representation
affine representation check that a point is infinite by the struct field
basic struct trait
This is commitment
elliptic curve rational points group
rational points group behaves as abelian group
extension field
This is fft field
This is used for fft and has roots of unity
field trait which ensures the existence of inverse for both multiplicative and additive arithmetic
hence field supports division for any element
G2 group pairing interface
group trait which supports additive and scalar arithmetic
additive and scalar arithmetic hold associative and distributive property
any element has its inverse and these is the identity in group
existence of inverse is ensured for only additive arithmetic
pairing abstraction
pairing function range field
parallelize compatible pallet
parity compatible pallet
This is polynomial
This has fft functionality and represents polynomial ring
This is prime field trait
rational point projective representation
projective representation check that a point is infinite by z coordinate
ring trait which supports additive and multiplicative arithmetics
both arithmetics hold associative and distributive property
default element is multiplicative generator
substrate runtime pallet