Trait zero_crypto::behave::Ring
source · pub trait Ring: Group + Mul<Output = Self> + MulAssign + PartialOrd + Ord + Default {
const MULTIPLICATIVE_IDENTITY: Self;
fn one() -> Self;
}Expand description
ring trait which supports additive and multiplicative arithmetics both arithmetics hold associative and distributive property default element is multiplicative generator